@@ -108,8 +108,11 @@ class BaseAddOn:
         blob = args.pop("json")
         if blob:
             blob = json.loads(blob)
-            if blob:
-                # merge json blob into the arguments
+            if "payload" in blob:
+                # merge v2 json blob into the arguments
+                args.update(blob["payload"])
+            elif blob:
+                # merge v1 json blob into the arguments
                 args.update(blob)
 
         # validate parameter data
@@ -235,8 +238,6 @@ class SoftTimeOutAddOn(AddOn):
             self.set_message("No progress was made, not re-running")
             return
 
-        # XXX dismiss the current run?
-
         self.client.post(
             "addon_runs/",
             json={
@@ -245,6 +246,10 @@ class SoftTimeOutAddOn(AddOn):
                 "documents": document_ids,
             },
         )
+        self.client.patch(
+            f"addon_runs/{self.id}/",
+            json={"dismissed": True},
+        )
 
     def get_documents(self):
         """Get documents from either selected or queried documents"""
